@@ -1113,6 +1113,34 @@ void CDocument::keyPressEvent (QKeyEvent *event)
       return;
      }
 
+#if QT_VERSION >= 0x050000
+
+  if (event->key() == Qt::Key_C && (event->modifiers().testFlag(Qt::ControlModifier)))
+     {
+      QString t = get();
+
+      if (t.isEmpty())
+         {
+          event->accept();
+          return;
+         }
+
+#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
+      t = t.replace (QChar::ParagraphSeparator, "\r\n");
+#elif defined(Q_OS_UNIX)
+      t = t.replace (QChar::ParagraphSeparator, "\n");
+#endif
+
+      QClipboard *clipboard = QApplication::clipboard();
+
+      clipboard->setText (t);
+
+      event->accept();
+      return;
+     }
+#endif
+
+
   QPlainTextEdit::keyPressEvent (event);
 }
 
@@ -1436,15 +1464,30 @@ QString CDocument::get_filename_at_cursor()
 
   QString x;
 
+  QString sep_start;
+  QString sep_end;
+
   if (markup_mode == "LaTeX")
+     {
+      sep_start = "{";
+      sep_end = "}";
+     }
+  else
+  if (markup_mode == "Markdown")
+     {
+      sep_start = "(";
+      sep_end = ")";
+     }
+
+  if (markup_mode == "LaTeX" || markup_mode == "Markdown")
      {
       int pos = textCursor().positionInBlock();
 
-      int end = s.indexOf ("}", pos);
+      int end = s.indexOf (sep_end, pos);
       if (end == -1)
          return x;
 
-      int start = s.lastIndexOf ("{", pos);
+      int start = s.lastIndexOf (sep_start, pos);
       if (start == -1)
          return x;
 
